# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2023.12.1] - (2023-12-23)

### Added

-   Add package data.
-   Add the class `FinTDA`.
-   Add example

### Changed

-   Due to PyPi problems changed the name from `finance-tda` to `fintda`
